@@ -20,14 +20,14 @@ test_that("new_fact_table works", {
       "nrow_agg"
     ),
     row.names = 1:24,
-    class = c("tbl_df",
-              "tbl", "data.frame", "fact_table"),
     name = "test",
     foreign_keys = c("when_available_key",
                      "when_key", "where_key", "who_key"),
     measures = c("deaths", "nrow_agg"),
     agg_functions = c("SUM", "SUM"),
-    nrow_agg = "nrow_agg"
+    nrow_agg = "nrow_agg",
+    class = c("fact_table", "tbl_df",
+              "tbl", "data.frame")
   )
 
   expect_equal(attributes(ft), res)
