@@ -9,11 +9,10 @@ test_that("rename_dimension works", {
     list(
       names = c("when_n_key", "week_ending_date", "week", "year"),
       row.names = integer(0),
-      class = c("tbl_df", "tbl", "data.frame",
-                "dimension_table"),
       name = "when_n",
       type = "role",
-      role_playing = "when_common"
+      role_playing = "when_common",
+      class = c("dimension_table", "tbl_df", "tbl", "data.frame")
     )
   )
   expect_equal(
@@ -28,15 +27,15 @@ test_that("rename_dimension works", {
         "nrow_agg"
       ),
       row.names = 1:24,
-      class = c("tbl_df",
-                "tbl", "data.frame", "fact_table"),
       name = "mrs_age",
       foreign_keys = c("when_n_key",
                        "when_available_key", "where_key", "who_key"),
       measures = c("deaths",
                    "nrow_agg"),
       agg_functions = c("SUM", "SUM"),
-      nrow_agg = "nrow_agg"
+      nrow_agg = "nrow_agg",
+      class = c("fact_table", "tbl_df",
+                "tbl", "data.frame")
     )
   )
 
@@ -51,8 +50,8 @@ test_that("rename_dimension works", {
       row.names = 1:9,
       name = "when_n",
       type = "role_playing",
-      class = c("tbl_df",
-                "tbl", "data.frame", "dimension_table")
+      class = c("dimension_table", "tbl_df",
+                "tbl", "data.frame")
     )
   )
   expect_equal(
@@ -60,11 +59,10 @@ test_that("rename_dimension works", {
     list(
       names = c("when_key", "week_ending_date", "week", "year"),
       row.names = integer(0),
-      class = c("tbl_df", "tbl", "data.frame",
-                "dimension_table"),
       name = "when",
       type = "role",
-      role_playing = "when_n"
+      role_playing = "when_n",
+      class = c("dimension_table", "tbl_df", "tbl", "data.frame")
     )
   )
   expect_equal(
@@ -77,10 +75,10 @@ test_that("rename_dimension works", {
         "data_availability_year"
       ),
       row.names = integer(0),
-      class = c("tbl_df", "tbl", "data.frame", "dimension_table"),
       name = "when_available",
       type = "role",
-      role_playing = "when_n"
+      role_playing = "when_n",
+      class = c("dimension_table", "tbl_df", "tbl", "data.frame")
     )
   )
 })
