@@ -15,15 +15,15 @@ test_that("rename_fact works", {
         "nrow_agg"
       ),
       row.names = 1:24,
-      class = c("tbl_df",
-                "tbl", "data.frame", "fact_table"),
       name = "age",
       foreign_keys = c("when_key",
                        "when_available_key", "where_key", "who_key"),
       measures = c("deaths",
                    "nrow_agg"),
       agg_functions = c("SUM", "SUM"),
-      nrow_agg = "nrow_agg"
+      nrow_agg = "nrow_agg",
+      class = c("fact_table", "tbl_df",
+                "tbl", "data.frame")
     )
   )
 })
